@@ -38,14 +38,23 @@ UUID_TYPE = "org.apache.cassandra.db.marshal.UUIDType"
 LEXICAL_UUID_TYPE = "org.apache.cassandra.db.marshal.LexicalType"
 TIME_UUID_TYPE = "org.apache.cassandra.db.marshal.TimeUUIDType"
 TIMESTAMP_TYPE = "org.apache.cassandra.db.marshal.DateType"
+COUNTER_TYPE = "org.apache.cassandra.db.marshal.CounterColumnType"
 
 
 def prepare(query, params):
-    # For every match of the form ":param_name", call marshal
-    # on kwargs['param_name'] and replace that section of the query
-    # with the result
-    new, count = re.subn(_param_re,
-                         lambda m: marshal(params[m.group(1)[1:]]), query)
+    """
+    For every match of the form ":param_name", call marshal
+    on kwargs['param_name'] and replace that section of the query
+    with the result
+    """
+    def repl(match):
+        name = match.group(1)[1:]
+        if name in params:
+            return marshal(params[name])
+        return ":%s" % name
+
+    new, count = re.subn(_param_re, repl, query)
+
     if len(params) > count:
         raise cql.ProgrammingError("More keywords were provided "
                                    "than parameters")
@@ -77,6 +86,15 @@ def unmarshal_int(bytestr):
     return decode_bigint(bytestr)
 
 
+def unmarshal_initializable_int(bytestr):
+    """
+    This is useful for counters, which may not be initialized (bytestring could be None).
+    """
+    if bytestr is None:
+        return None
+    return decode_bigint(bytestr)
+
+
 _long_packer = struct.Struct('>q')
 
 
@@ -101,7 +119,8 @@ unmarshallers = {BYTES_TYPE:        unmarshal_noop,
                  UUID_TYPE:         unmarshal_uuid,
                  LEXICAL_UUID_TYPE: unmarshal_uuid,
                  TIME_UUID_TYPE:    unmarshal_uuid,
-                 TIMESTAMP_TYPE:    unmarshal_timestamp}
+                 TIMESTAMP_TYPE:    unmarshal_timestamp,
+                 COUNTER_TYPE:      unmarshal_initializable_int}
 
 
 def decode_bigint(term):
