@@ -31,9 +31,12 @@ class BasicLockTest(BaseTestCase):
         self.client = mock.create_autospec(CQLClient)
         self.table_name = 'lock'
 
-        def _side_effect(*args, **kwargs):
-            return defer.succeed(1)
-        self.client.execute.side_effect = _side_effect
+        self.responses = [1]
+
+        def _execute(*args, **kwargs):
+            return defer.succeed(self.responses.pop(0))
+
+        self.client.execute.side_effect = _execute
 
     def test__read_lock(self):
         lock_uuid = uuid.uuid1()
@@ -270,6 +273,113 @@ class BasicLockTest(BaseTestCase):
         self.assertFired(d)
         self.client.execute.assert_called_once_with(*expected)
 
+    @mock.patch('silverberg.lock.uuid.uuid1', return_value='claim_uuid')
+    def test_acquire_logs(self, uuid1):
+        """
+        When lock is acquired, it logs with time taken to acquire the log
+        """
+        lock_uuid = 'lock_uuid'
+        log = mock.MagicMock(spec=['msg'])
+        clock = task.Clock()
+        lock = BasicLock(self.client, self.table_name, lock_uuid, max_retry=1,
+                         retry_wait=3, reactor=clock, log=log)
+        self.responses = [
+            None,   # _write_lock
+            [{'lockId': lock._lock_id, 'claimId': 'wait for it..'}],  # _read_lock
+            None,   # delete for release lock
+            None,   # _write_lock again
+            [{'lockId': lock._lock_id, 'claimId': lock._claim_id}]  # _read_lock
+        ]
+
+        d = lock.acquire()
+
+        clock.advance(5)
+        self.assertEqual(self.assertFired(d), True)
+        log.msg.assert_called_with('Acquired lock in 5.0 seconds',
+                                   lock_acquire_time=5.0, lock_id=lock_uuid,
+                                   claim_id='claim_uuid')
+
+    @mock.patch('silverberg.lock.uuid.uuid1', return_value='claim_uuid')
+    def test_release_logs(self, uuid1):
+        """
+        When lock is released, it logs with time the lock was held
+        """
+        lock_uuid = 'lock_uuid'
+        log = mock.MagicMock(spec=['msg'])
+        clock = task.Clock()
+        lock = BasicLock(self.client, self.table_name, lock_uuid, max_retry=1,
+                         retry_wait=3, reactor=clock, log=log)
+        self.responses = [
+            None,   # _write_lock
+            [{'lockId': lock._lock_id, 'claimId': lock._claim_id}],  # _read_lock
+            None   # delete for release lock
+        ]
+
+        lock.acquire()
+        clock.advance(34)
+        lock.release()
+
+        log.msg.assert_called_with('Released lock. Was held for 34.0 seconds',
+                                   lock_held_time=34.0, lock_id=lock_uuid,
+                                   claim_id='claim_uuid')
+
+    @mock.patch('silverberg.lock.uuid.uuid1', return_value='claim_uuid')
+    def test_lock_acquire_failure_logged(self, uuid1):
+        """
+        If lock acquisition fails due to BusyLockError, it is logged along with time taken
+        """
+        lock_uuid = 'lock_uuid'
+        log = mock.MagicMock(spec=['msg'])
+        clock = task.Clock()
+        lock = BasicLock(self.client, self.table_name, lock_uuid, max_retry=1,
+                         retry_wait=3, reactor=clock, log=log)
+        self.responses = [
+            None,   # _write_lock
+            [{'lockId': lock._lock_id, 'claimId': 'wait for it..'}],  # _read_lock
+            None,   # delete for release lock
+            None,   # _write_lock again
+            [{'lockId': lock._lock_id, 'claimId': 'nope'}],  # _read_lock
+            None   # delete again for release lock
+        ]
+
+        d = lock.acquire()
+        clock.advance(3)
+        f = self.failureResultOf(d, BusyLockError)
+        log.msg.assert_called_with('Could not acquire lock in 3.0 seconds due to ' + str(f),
+                                   lock_acquire_fail_time=3.0, reason=f, lock_id=lock_uuid,
+                                   claim_id='claim_uuid')
+
+    @mock.patch('silverberg.lock.uuid.uuid1', return_value='claim_uuid')
+    def test_lock_acquire_anyfailure_logged(self, uuid1):
+        """
+        If lock acquisition fails due to any error, it is logged along with time taken
+        """
+        lock_uuid = 'lock_uuid'
+        log = mock.MagicMock(spec=['msg'])
+        clock = task.Clock()
+        lock = BasicLock(self.client, self.table_name, lock_uuid, max_retry=1,
+                         retry_wait=3, reactor=clock, log=log)
+        self.responses = [
+            None,   # _write_lock
+            [{'lockId': lock._lock_id, 'claimId': 'wait for it..'}],  # _read_lock
+            None,   # delete for release lock
+            None,   # _write_lock again
+        ]
+
+        def _execute(*args, **kwargs):
+            if not self.responses:
+                return defer.fail(ValueError('hmm'))
+            return defer.succeed(self.responses.pop(0))
+
+        self.client.execute.side_effect = _execute
+
+        d = lock.acquire()
+        clock.advance(3)
+        f = self.failureResultOf(d, ValueError)
+        log.msg.assert_called_with('Could not acquire lock in 3.0 seconds due to ' + str(f),
+                                   lock_acquire_fail_time=3.0, reason=f, lock_id=lock_uuid,
+                                   claim_id='claim_uuid')
+
 
 class WithLockTest(BaseTestCase):
     """Test the lock context manager."""
